@@ -4,7 +4,8 @@
 
 ;; Author: Milan Glacier <dev@milanglacier.com>
 ;; Maintainer: Milan Glacier <dev@milanglacier.com>
-;; Version: 0.7.1
+;; Package-Version: 20251015.1814
+;; Package-Revision: 6d48b96f09ce
 ;; URL: https://github.com/milanglacier/minuet-ai.el
 ;; Package-Requires: ((emacs "29") (plz "0.9") (dash "2.19.1"))
 
@@ -61,13 +62,10 @@
   "Debounce delay in seconds for auto-suggestions."
   :type 'number)
 
-(define-obsolete-variable-alias 'minuet-auto-suggestion-block-functions
-  'minuet-auto-suggestion-block-predicates "0.7.1")
-
-(defcustom minuet-auto-suggestion-block-predicates '(minuet-evil-not-insert-state-p)
+(defcustom minuet-auto-suggestion-block-functions '(minuet-evil-not-insert-state-p)
   "List of functions to determine whether auto-suggestions should be blocked.
 
-Each functions should return non-nil if auto-suggestions should be
+Each function should return non-nil if auto-suggestions should be
 blocked.  If any function in this list returns non-nil,
 auto-suggestions will not be shown."
   :type '(repeat function))
@@ -84,8 +82,6 @@ auto-suggestions will not be shown."
 (defvar-local minuet--current-overlay nil
   "Overlay used for displaying the current suggestion.")
 
-(defvar-local minuet--last-synced-point nil
-  "Last point where typed text was synced with the suggestion overlay.")
 
 (defvar-local minuet--last-point nil
   "Last known cursor position for suggestion overlay.")
@@ -494,38 +490,10 @@ Also cancel any pending requests unless NO-CANCEL is t."
   (and minuet--last-point
        (not (eq minuet--last-point (point)))))
 
-(defun minuet--sync-suggestion-with-typed-text ()
-  "Update the suggestion when the typed text matches its prefix.
-Return non-nil when the completion was preserved or updated."
-  (if-let* ((suggestions minuet--current-suggestions)
-            (has-overlay minuet--current-overlay)
-            (last-point minuet--last-point)
-            (cursor-moved-forward (> (point) last-point))
-            (index (or minuet--current-suggestion-index 0))
-            (current-suggestion (nth index suggestions))
-            (typed (buffer-substring-no-properties last-point (point)))
-            (current-suggestion-matches-typed
-             (and (string-prefix-p typed current-suggestion)
-                  (length> current-suggestion (length typed))))
-            (matched-suggestions
-             (cl-loop for suggestion in suggestions
-                      for i from 0
-                      when (string-prefix-p typed suggestion)
-                      collect (cons i (substring suggestion (length typed)))))
-            (new-index (or (cl-position index matched-suggestions :key #'car) 0))
-            (new-suggestions (mapcar #'cdr matched-suggestions)))
-      (progn
-        (minuet--cleanup-suggestion)
-        (minuet--display-suggestion new-suggestions new-index)
-        (setq minuet--last-synced-point (point))
-        t)
-    (setq minuet--last-synced-point nil)))
-
 (defun minuet--on-cursor-moved ()
   "Minuet event on cursor moved."
   (when (minuet--cursor-moved-p)
-    (unless (minuet--sync-suggestion-with-typed-text)
-      (minuet--cleanup-suggestion))))
+    (minuet--cleanup-suggestion)))
 
 (defun minuet--display-suggestion (suggestions &optional index)
   "Display suggestion from SUGGESTIONS at INDEX using an overlay at point."
@@ -539,18 +507,6 @@ Return non-nil when the completion was preserved or updated."
               (total (length suggestions))
               (index (mod (or index 0) total))
               (suggestion (nth index suggestions))
-              ;; Adjust the suggestion text displayed in the overlay
-              ;; by replacing empty lines with a space. This ensures
-              ;; that when the current line is empty, the overlay text
-              ;; is correctly positioned after the cursor rather than
-              ;; before it.
-              (overlay-text (replace-regexp-in-string "^$" " " suggestion))
-              (overlay-text (propertize
-                             (format "%s%s"
-                                     overlay-text
-                                     (if (= total minuet-n-completions 1) ""
-                                       (format " (%d/%d)" (1+ index) total)))
-                             'face 'minuet-suggestion-face))
               ;; 'Display' is used when not at the end-of-line to
               ;; ensure proper overlay positioning. Other methods,
               ;; such as `after-string' or `before-string', fail to
@@ -572,9 +528,16 @@ Return non-nil when the completion was preserved or updated."
     ;; HACK: Adapted from copilot.el We add a 'cursor text property to the
     ;; first character of the suggestion to simulate the visual effect of
     ;; placing the overlay after the cursor
-    (put-text-property 0 1 'cursor t overlay-text)
+    (put-text-property 0 1 'cursor t suggestion)
     (overlay-put ov ov-method
-                 (concat overlay-text offset-char))
+                 (concat
+                  (propertize
+                   (format "%s%s"
+                           suggestion
+                           (if (= total minuet-n-completions 1) ""
+                             (format " (%d/%d)" (1+ index) total)))
+                   'face 'minuet-suggestion-face)
+                  offset-char))
     (overlay-put ov 'minuet t)
     (setq minuet--current-overlay ov)
     (minuet-active-mode 1)))
@@ -583,22 +546,22 @@ Return non-nil when the completion was preserved or updated."
 (defun minuet-next-suggestion ()
   "Cycle to next suggestion."
   (interactive)
-  (if-let* ((suggestions minuet--current-suggestions)
-            (_ minuet--current-overlay)
-            (next-index (mod (1+ minuet--current-suggestion-index)
-                             (length suggestions))))
-      (minuet--display-suggestion suggestions next-index)
+  (if (and minuet--current-suggestions
+           minuet--current-overlay)
+      (let ((next-index (mod (1+ minuet--current-suggestion-index)
+                             (length minuet--current-suggestions))))
+        (minuet--display-suggestion minuet--current-suggestions next-index))
     (minuet-show-suggestion)))
 
 ;;;###autoload
 (defun minuet-previous-suggestion ()
   "Cycle to previous suggestion."
   (interactive)
-  (if-let* ((suggestions minuet--current-suggestions)
-            (_ minuet--current-overlay)
-            (prev-index (mod (1- minuet--current-suggestion-index)
-                             (length suggestions))))
-      (minuet--display-suggestion suggestions prev-index)
+  (if (and minuet--current-suggestions
+           minuet--current-overlay)
+      (let ((prev-index (mod (1- minuet--current-suggestion-index)
+                             (length minuet--current-suggestions))))
+        (minuet--display-suggestion minuet--current-suggestions prev-index))
     (minuet-show-suggestion)))
 
 ;;;###autoload
@@ -760,6 +723,7 @@ CONTEXT is a plist with :before-cursor and :after-cursor fields.
 Returns the filtered item after trimming overlapping parts."
   (when (null item)
     (cl-return-from minuet--filter-text nil))
+
   (when (null context)
     (cl-return-from minuet--filter-text item))
 
@@ -768,22 +732,27 @@ Returns the filtered item after trimming overlapping parts."
   (let* ((before-cursor (plist-get context :before-cursor))
          (after-cursor (plist-get context :after-cursor))
          (filtered-item item))
+
     ;; Filter against before-cursor context (trim from prefix)
-    (when-let* ((before-cursor before-cursor)
-                (should-filter (> minuet-before-cursor-filter-length 0))
-                (before-cursor (string-trim before-cursor))
-                (match (minuet-find-longest-match filtered-item before-cursor))
-                (should-filter (and (not (string-empty-p match))
-                                    (>= (length match) minuet-before-cursor-filter-length))))
-      (setq filtered-item (substring filtered-item (length match))))
+    (when (and before-cursor
+               (> minuet-before-cursor-filter-length 0))
+      (setq before-cursor (string-trim before-cursor))
+      (let* ((match (minuet-find-longest-match filtered-item before-cursor)))
+        (when (and match
+                   (not (string-empty-p match))
+                   (>= (length match) minuet-before-cursor-filter-length))
+          (setq filtered-item (substring filtered-item (length match))))))
+
     ;; Filter against after-cursor context (trim from suffix)
-    (when-let* ((after-cursor after-cursor)
-                (should-filter (> minuet-after-cursor-filter-length 0))
-                (after-cursor (string-trim after-cursor))
-                (match (minuet-find-longest-match after-cursor filtered-item))
-                (should-filter (and (not (string-empty-p match))
-                                    (>= (length match) minuet-after-cursor-filter-length))))
-      (setq filtered-item (substring filtered-item 0 (- (length filtered-item) (length match)))))
+    (when (and after-cursor
+               (> minuet-after-cursor-filter-length 0))
+      (setq after-cursor (string-trim after-cursor))
+      (let* ((match (minuet-find-longest-match after-cursor filtered-item)))
+        (when (and match
+                   (not (string-empty-p match))
+                   (>= (length match) minuet-after-cursor-filter-length))
+          (setq filtered-item (substring filtered-item 0 (- (length filtered-item) (length match)))))))
+
     filtered-item))
 
 (cl-defun minuet-find-longest-match (a b)
@@ -823,10 +792,10 @@ The filter sequence is obtained from CONTEXT."
                            (replace-regexp-in-string "^data: " "" line)
                            :object-type 'plist :array-type 'list)))
                   (text (ignore-errors
-                          (funcall get-text-fn json)))
-                  (text-not-empty (and (stringp text)
-                                       (not (string= text "")))))
-        (push text result)))
+                          (funcall get-text-fn json))))
+        (when (and (stringp text)
+                   (not (equal text "")))
+          (push text result))))
     (setq result (apply #'concat (nreverse result)))
     (if (equal result "")
         (progn
@@ -889,11 +858,12 @@ used to accumulate text output from a process.  After execution,
 (defun minuet-accept-suggestion ()
   "Accept the current overlay suggestion."
   (interactive)
-  (when-let* ((suggestions minuet--current-suggestions)
-              (_ minuet--current-overlay)
-              (suggestion (nth minuet--current-suggestion-index suggestions)))
-    (minuet--cleanup-suggestion)
-    (insert suggestion)))
+  (when (and minuet--current-suggestions
+             minuet--current-overlay)
+    (let ((suggestion (nth minuet--current-suggestion-index
+                           minuet--current-suggestions)))
+      (minuet--cleanup-suggestion)
+      (insert suggestion))))
 
 ;;;###autoload
 (defun minuet-dismiss-suggestion ()
@@ -913,21 +883,9 @@ many lines.  Without a prefix argument, accept only the first line."
                             minuet--current-suggestions))
            (lines (split-string suggestion "\n"))
            (n (or n 1))
-           (selected-lines (seq-take lines n))
-           (remaining-lines (seq-drop lines n))
-           (remaining-suggestion (when remaining-lines
-                                   (string-join remaining-lines "\n"))))
+           (selected-lines (seq-take lines n)))
       (minuet--cleanup-suggestion)
-      (insert (string-join selected-lines "\n"))
-      (when remaining-suggestion
-        (insert "\n") ;; There is a remaining suggestion, so move to the next line.
-        ;; NOTE: We do not need to worry about Minuet
-        ;; automatically triggering the next suggestion upon
-        ;; continuous acceptance.  Minuet only attempts
-        ;; auto-suggestion when the last command was not a Minuet
-        ;; command. Since we have just accepted partial lines, the
-        ;; last command is indeed a Minuet command.
-        (minuet--display-suggestion (list remaining-suggestion) 0)))))
+      (insert (string-join selected-lines "\n")))))
 
 ;;;###autoload
 (defun minuet-complete-with-minibuffer ()
@@ -1350,8 +1308,7 @@ to be called when completion items arrive."
 (defun minuet--maybe-show-suggestion ()
   "Show suggestion with debouncing and throttling."
   (when (and (minuet--is-not-on-throttle)
-             (not (minuet--is-minuet-command))
-             (not (eq (point) minuet--last-synced-point)))
+             (not (minuet--is-minuet-command)))
     (when minuet--debounce-timer
       (cancel-timer minuet--debounce-timer))
     (setq minuet--debounce-timer
@@ -1362,8 +1319,7 @@ to be called when completion items arrive."
                (when (and (eq buffer (current-buffer))
                           (or (null minuet--auto-last-point)
                               (not (eq minuet--auto-last-point (point))))
-                          (not (run-hook-with-args-until-success
-                                'minuet-auto-suggestion-block-predicates)))
+                          (not (run-hook-with-args-until-success 'minuet-auto-suggestion-block-functions)))
                  (setq minuet--last-auto-suggestion-time (current-time)
                        minuet--auto-last-point (point))
                  (minuet-show-suggestion))))))))
@@ -1436,9 +1392,14 @@ settings, as an alternative to manual configuration via `setq' and
 `openai-fim-compatible' providers, users will be prompted to specify
 their endpoint and API key."
   (interactive)
-  (let* ((providers (mapcar #'cddr (cdr (get 'minuet-provider 'custom-type))))
+  (let* ((providers '(("OpenAI" . openai)
+                      ("Claude" . claude)
+                      ("Codestral" . codestral)
+                      ("OpenAI Compatible" . openai-compatible)
+                      ("OpenAI FIM Compatible" . openai-fim-compatible)
+                      ("Gemini" . gemini)))
          (provider-name (completing-read "Select provider: " providers nil t))
-         (provider (car (alist-get provider-name providers nil nil #'equal)))
+         (provider (alist-get provider-name providers nil nil #'equal))
          (options-sym (intern (format "minuet-%s-options" provider)))
          (options (symbol-value options-sym))
          (current-model (plist-get options :model))
